@@ -14,11 +14,14 @@ void DownloadManager::abort()
     if(currentDownload.isEmpty()){
         return;
     }
+    emit dlMessage(QString("\"%1\" download was canceled").arg(downloadQueue.at(0).value("title")));
+    disconnect(dlReply, SIGNAL(finished()), this, SLOT(downloadFinished()));
+    downloadQueue.clear();
     dlReply->abort();
+    dlReply->deleteLater();
     file.close();
     file.remove();
-    dlReply->deleteLater();
-    emit dlMessage(QString("\"%1\" download was canceled").arg(downloadQueue.at(0).value("title")));
+    emit finished();
 }
 
 void DownloadManager::append(const QList<QMap<QString, QString> > &videos)
@@ -179,15 +182,14 @@ void DownloadManager::processVideoUrl(QNetworkReply *reply)
         if (string.contains("url_encoded_fmt_stream_map=")){
             QString str(QByteArray::fromPercentEncoding(string.split("url_encoded_fmt_stream_map=").at(1).split("&").at(0).toAscii()));
             QStringList strlist = str.split(",");
-            if (strlist.size() > 2) {
-                for (int i = 0; i < strlist.size(); ++i){
-                    if(strlist.at(i).endsWith("itag=18")){
-                        QString url(QByteArray::fromPercentEncoding(strlist.at(strlist.size()-3).split("&").at(0).split("=").at(1).toAscii()));
-                        if (url.startsWith("http://o-o.preferred.") && !usePreferredServer){
-                            url.remove("o-o.preferred.").remove(7, url.indexOf(".") - 6);
-                        }
-                        mp4url = url;
+            for (int i = 0; i < strlist.size(); ++i){
+                if(strlist.at(i).endsWith("&itag=18")){
+                    QString url(QByteArray::fromPercentEncoding(strlist.at(i).split("&").at(0).split("=").at(1).toAscii()));
+                    if (url.startsWith("http://o-o.preferred.") && !usePreferredServer){
+                        url.remove("o-o.preferred.").remove(7, url.indexOf(".") - 6);
                     }
+                    mp4url = url;
+                    break;
                 }
             }
         }
