@@ -1,5 +1,4 @@
 #include "networkaccess.h"
-#include <QDebug>
 
 NetworkAccess::NetworkAccess(QObject *parent) :
     QObject(parent)
@@ -329,15 +328,14 @@ void NetworkAccess::processVideoUrl(QNetworkReply *reply)
         if (string.contains("url_encoded_fmt_stream_map=")){
             QString str(QByteArray::fromPercentEncoding(string.split("url_encoded_fmt_stream_map=").at(1).split("&").at(0).toAscii()));
             QStringList strlist = str.split(",");
-            if (strlist.size() > 2) {
-                for (int i = 0; i < strlist.size(); ++i){
-                    if(strlist.at(i).endsWith("itag=18")){
-                        QString url(QByteArray::fromPercentEncoding(strlist.at(strlist.size()-3).split("&").at(0).split("=").at(1).toAscii()));
-                        if (url.startsWith("http://o-o.preferred.") && !usePreferredServer){
-                            url.remove("o-o.preferred.").remove(7, url.indexOf(".") - 6);
-                        }
-                        mp4url = url;
+            for (int i = 0; i < strlist.size(); ++i){
+                if(strlist.at(i).endsWith("&itag=18")){
+                    QString url(QByteArray::fromPercentEncoding(strlist.at(i).split("&").at(0).split("=").at(1).toAscii()));
+                    if (url.startsWith("http://o-o.preferred.") && !usePreferredServer){
+                        url.remove("o-o.preferred.").remove(7, url.indexOf(".") - 6);
                     }
+                    mp4url = url;
+                    break;
                 }
             }
         }
